Commands
========

.. automodule:: workspace.commands.bump
   :members:

.. automodule:: workspace.commands.checkout
   :members:

.. automodule:: workspace.commands.clean
   :members:

.. automodule:: workspace.commands.commit
   :members:

.. automodule:: workspace.commands.diff
   :members:

.. automodule:: workspace.commands.log
   :members:

.. automodule:: workspace.commands.publish
   :members:

.. automodule:: workspace.commands.push
   :members:

.. automodule:: workspace.commands.setup
   :members:

.. automodule:: workspace.commands.status
   :members:

.. automodule:: workspace.commands.test
   :members:

.. automodule:: workspace.commands.update
   :members:

